@@ -2,7 +2,7 @@
 ;;; -*- coding: iso-8859-1 -*-
 ;;;
 ;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012,
-;;;   2015 Ludovic Courts <ludo@gnu.org>
+;;;   2015, 2018 Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
@@ -44,7 +44,7 @@
 
 
 ;*---------------------------------------------------------------------*/
-;*    Html configuration                                               */
+;*    HTML configuration                                               */
 ;*---------------------------------------------------------------------*/
 (let* ((he (find-engine 'html))
        (tro (markup-writer-get 'tr he)))
@@ -68,7 +68,70 @@
       :action (lambda (n e)
 		 (let ((c (engine-custom e 'title-background)))
 		    (markup-option-add! n :bg c)
-		    (output n e tro)))))
+		    (output n e tro))))
+
+   (markup-writer 'doc-markup he
+      :action (lambda (n e)
+                (let ((protos (markup-option n 'prototypes))
+                      (opts   (markup-option n 'options))
+                      (params (markup-option n 'parameters))
+                      (see    (markup-option n 'see-also)))
+                  (display "<div class=\"skribilo-doc-markup\">")
+                  (for-each (lambda (p)
+                              (output (! "\n<div \
+  class=\"skribilo-api-prototype\">$1</div>" p) e))
+                            protos)
+                  (for-each (match-lambda
+                              ((name (engines ...) desc)
+                               (output (! "\n<div
+  class=\"skribilo-api-option\"> \
+  <span class=\"skribilo-api-option-name\">$1</span> \
+  <span class=\"skribilo-api-option-description\">$2</span> \
+  <span class=\"skribilo-api-option-engines\">$3</span></div>"
+                                          name desc engines)
+                                       e)))
+                            (or opts '()))
+
+                  (for-each (match-lambda
+                              ((param . desc)
+                               (output (! "\n<div \
+  class=\"skribilo-api-argument\"> \
+  <span class=\"skribilo-api-argument-name\">$1</span> \
+  <span class=\"skribilo-api-argument-description\">$2</span></div>"
+                                          param desc)
+                                       e)))
+                            (or params '()))
+
+                  (when (pair? see)
+                    (output (! "<div class=\"skribilo-api-see-also\">\
+See also $1</div>"
+                               (punctuate see))
+                            e))
+
+                  (display "</div>\n"))))
+
+  (markup-writer 'doc-engine he
+    :action (lambda (n e)
+              (let ((customs  (markup-option n 'customs))
+                    (defaults (markup-option n 'defaults)))
+
+                (display "\n<div class=\"skribilo-doc-engine\">")
+                (for-each (match-lambda
+                            ((name desc)
+                             (output (! "\
+<div class=\"skribilo-api-engine-custom\"> \
+<span class=\"skribilo-api-engine-custom-name\">$1</span> \
+<span class=\"skribilo-api-engine-custom-description\"> \
+<span class=\"skribilo-api-engine-custom-default\">default: <tt>$2</tt></span> \
+$3</span></div>\n"
+                                        (object->string name)
+                                        (match (assq name defaults)
+                                          ((_ dflt)
+                                           (object->string dflt)))
+                                        desc)
+                                     e)))
+                          customs)
+                (display "\n</div>\n")))))
 
 ;*---------------------------------------------------------------------*/
 ;*    LaTeX configuration                                              */
@@ -92,6 +155,13 @@
 ;*---------------------------------------------------------------------*/
 (let ((le (find-engine 'lout)))
 
+  (engine-custom-set! le 'initial-font "Palatino Base 11p")
+
+  ;; XXX: Adding 'marginkerning' makes Lout 3.40 segfault.
+  (engine-custom-set! le 'initial-break
+                      "unbreakablefirst unbreakablelast \
+hyphen adjust 1.3fx")
+
   (let ((defs (engine-custom le 'inline-definitions-proc)))
     (engine-custom-set! le 'inline-definitions-proc
                         (lambda (e)
@@ -115,14 +185,20 @@ def @SkribiloExample named @Title {} right x {
       @Diag { @CurveBox
                 outlinestyle { noline }
                 paint { rgb 0.95 0.95 0.87 }
-                font { 0.9f }
+                font { 9p }
 		break { 0.9fx }
               @HExpand @Body } }
   { x }
 }\n\n"
                            ))))
 
-  (markup-writer 'doc-markup
+  ;; Compared to the default 'prog' writer, this one uses a smaller font.
+  (markup-writer 'prog le
+     :options '(:line :mark)
+     :before "\n{ Courier Base 9p } @Font { lines nohyphen 0.9fx } @Break lout @Space {\n"
+     :after "\n} # @Break\n")
+
+  (markup-writer 'doc-markup le
     :action (lambda (n e)
               (let ((protos (markup-option n 'prototypes))
                     (opts   (markup-option n 'options))
@@ -164,7 +240,7 @@ def @SkribiloExample named @Title {} right x {
 
                 (display "\n@LP\n"))))
 
-  (markup-writer 'doc-engine
+  (markup-writer 'doc-engine le
     :action (lambda (n e)
               (let ((customs  (markup-option n 'customs))
                     (defaults (markup-option n 'defaults)))
@@ -639,78 +715,7 @@ def @SkribiloExample named @Title {} right x {
 				 (define-markup-formals def)
 				 dargs))
 			     others od))))
-	  ;; doc table
-	  (define (doc-markup.html)
-	     (let ((df (map (lambda (f)
-			       (tr :bg *prgm-skribe-color*
-				  (td :colspan 2 :width 20. :align 'left
-				     (param (car f)) )
-				  (td :align 'left :width 80. (cadr f))))
-			    dformals))
-		   (dr (and (pair? drest)
-			    (tr :bg *prgm-skribe-color*
-			       (td :align 'left 
-				  :valign 'top
-				  :colspan 2 
-				  :width 20.
-				  (param (cadr (car drest))))
-			       (td :align 'left :width 80. 
-				  (caddr (car drest))))))
-		   (do (map (lambda (f)
-			       (tr :bg *prgm-skribe-color*
-				  (td :align 'left 
-				     :valign 'top
-				     :width 10.
-				     (param (car f)))
-				  (td :align 'left 
-				     :valign 'top
-				     :width 20.
-				     (opt-engine-support (car f)))
-				  (td :align 'left :width 70. (cadr f))))
-			    doptions))
-		   (so (map (lambda (x)
-			       (let ((s (symbol->string x)))
-				  (list 
-				   (ref :mark s :text (code s))
-				   " ")))
-			    see-also)))
-		(table :&location &invocation-location
-                   :border (if (engine-format? "latex") 1 0)
-		   :width (if (engine-format? "latex") #f *prgm-width*)
-		   `(,(tr :class 'api-table-prototype
-			 (th :colspan 3 :align 'left :width *prgm-width*
-			    "prototype"))
-		     ,@(map (lambda (p)
-			       (tr :bg *prgm-skribe-color*
-				  (td :colspan 3 :width *prgm-width*
-				     :align 'left  p)))
-			    p+)
-		     ,@(if (pair? do)
-			   `(,(tr :class 'api-table-header
-				 (th :align 'left "option" 
-				    :width 10.) 
-				 (th :align 'center "engines"
-				    :width 20.)
-				 (th "description"))
-			     ,@do)
-			   '())
-		     ,@(if (or (pair? df) dr)
-			   `(,(tr :class 'api-table-header
-				 (th :colspan 2 
-				    :align 'left 
-				    :width 30.
-				    "argument") 
-				 (th "description"))
-			     ,@(if (pair? df) df '())
-			     ,@(if dr (list dr) '()))
-			   '())
-		     ,@(if (pair? so)
-			   `(,(tr :class 'api-table-header
-				 (th :colspan 3 :align 'left 
-				    (it "See also")))
-			     ,(tr :bg *prgm-skribe-color*
-				 (td :colspan 3 :align 'left so)))
-			   '())))))
+
 	  ;; doc enumerate
 	  (define (doc-markup.latex)
 	     (let ((df (map (lambda (f)
@@ -797,11 +802,8 @@ def @SkribiloExample named @Title {} right x {
 		(cond
 		   ((engine-format? "latex")
 		    (doc-markup.latex))
-                   ((or (engine-format? "lout")
-                        (engine-format? "info"))
-                    (doc-markup.generic))
-		   (else
-		    (center (doc-markup.html)))))))))
+                   (else
+                    (doc-markup.generic))))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    doc-engine ...                                                   */
@@ -829,7 +831,8 @@ def @SkribiloExample named @Title {} right x {
                       ((engine-format? "latex" e)
                        (skribe-warning 3 "'doc-engine' not rendered in LaTeX")
                        #f)
-                      ((engine-format? "lout" e)
+                      ((or (engine-format? "lout" e)
+                           (engine-format? "html" e))
                        (list (map (lambda (c)
                                     (index (symbol->string (car c))
                                            :index idx
