@@ -1,7 +1,7 @@
 ;;; location.scm -- Skribilo source location.
 ;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2007, 2009, 2010, 2012  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2007, 2009, 2010, 2012, 2013, 2015  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 ;;;
 ;;;
@@ -27,7 +27,8 @@
   :export (<location> location? ast-location
 	   location-file location-line location-column
            invocation-location
-           source-properties->location))
+           source-properties->location
+           location->string))
 
 ;;; Author:  Ludovic Courts
 ;;;
@@ -62,7 +63,7 @@
 	       (lenf  (string-length fname))
 	       (file  (if (and (string-prefix? pwd fname len)
 			       (> lenf len))
-			  (substring fname len (+ 1 (string-length fname)))
+			  (substring fname len (string-length fname))
 			  fname)))
 	  (format #f "~a, line ~a" file line))
 	"no source location")))
@@ -113,4 +114,11 @@ etc."
                 :line (and line (+ line 1))
                 :column (and col (+ col 1))))))
 
+(define (location->string loc)
+  "Return a user-friendly representation of LOC."
+  (if (location? loc)
+      (format #f "~a:~a:~a:" (location-file loc) (location-line loc)
+              (location-column loc))
+      "<unknown-location>:"))
+
 ;;; location.scm ends here.
