@@ -1,22 +1,23 @@
 ;;; eq.scm  --  An equation formatting package.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012  Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo package eq)
   :autoload   (skribilo ast)    (markup? find1-up)
@@ -27,7 +28,7 @@
   :use-module (skribilo condition)
   :use-module (skribilo utils syntax)
   :use-module (skribilo utils keywords) ;; `the-options', etc.
-  :autoload   (skribilo package base) (it symbol sub sup)
+  :use-module (skribilo package base)
   :autoload   (skribilo engine lout)  (lout-illustration)
   :autoload   (skribilo resolve)      (resolve-counter)
 
@@ -50,7 +51,7 @@
 ;;;
 ;;; Code:
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 
